Inheritance
:::::::::::

.. toctree::
   :caption: Inheritance
   :maxdepth: 2

   01-PillarsOfOop.rst
   02-IntroToInheritance.rst
   03-Extending.rst                                                                                                
   04-ReuseThroughComposition.rst                                                                                  
   05-ClassDiagrams.rst                                                                                            
   06-CompositionVsInheritance.rst                                                                                 
   07-CaseStudy.rst
   